Rosetta — Django Rosetta 0.7.10 documentation

# Rosetta

Rosetta is a Django application that eases the translation process of your Django projects.

Because it doesn’t export any models, Rosetta doesn’t create any tables in your project’s database. Rosetta can be installed and uninstalled by simply adding and removing a single entry in your project’s INSTALLED_APPS and a single line in your main `urls.py` file.

## Features

- Database independent
- Reads and writes your project’s gettext catalogs (po and mo files)
- Installed and uninstalled in under a minute
- Uses Django’s admin interface CSS

# Contents:

- Installation
  - Requirements
  - Install Rosetta
  - Testing
  - Security
- Settings
  - Storages
- Usage
  - Generate a batch of files to translate
  - Translate away!
  - Translating Rosetta itself
- Version History
  - Version 0.7.10
  - Version 0.7.9
  - Version 0.7.8
  - Version 0.7.7
  - Version 0.7.6
  - Version 0.7.5
  - Version 0.7.4
  - Version 0.7.3
  - Version 0.7.2
  - Version 0.7.1
  - Version 0.7.0
  - Version 0.6.8
  - Version 0.6.7
  - Version 0.6.6
  - Version 0.6.5
  - Version 0.6.4
  - Version 0.6.3